"use client"

import { Box, Flex, Icon, useToast } from "@chakra-ui/react";
import { Button, FormControl, FormLabel, Text, useColorModeValue } from "@chakra-ui/react";
import { InputWrapper } from "@/components/fields/Fields";
import prepareValidationSchema, { FormObject } from "@/utils/validation-schema";
import { useEffect, useMemo, useRef, useState } from "react";
import FormComponent from "@/components/form/Form";
import CustomCard from "@/components/card/Card";
import { useGeneral } from "@/contexts/GeneralContext";
import { MdOutlineRemoveRedEye } from "react-icons/md";
import { RiEyeCloseLine } from "react-icons/ri";
import { useRouter } from "next/navigation";
import { signOut } from "next-auth/react";
import { resetPassword } from "@/app/lib/user/action";

interface formValues {
  coins: string;
}

export default function ChangePassword() {
  const { isUser } = useGeneral();
  const toast = useToast();
  const router = useRouter();

  // page styles
  const textColor = useColorModeValue("secondaryGray.900", "white");
  const brandStars = useColorModeValue("brand.500", "brand.400");
  const textColorSecondary = "gray.400";

  const formFields: FormObject[] = [
    {
      name: "password",
      label: "Password",
      min: 8,
      type: "text",
      defaultValue: "",
      required: true,
    },
  ];


  // logic values
  const formRef = useRef(null);
  const [dynamicFormField, setDynamicFormField] = useState(formFields);
  const formDetails = useMemo(() => prepareValidationSchema(dynamicFormField), [dynamicFormField]);
  const [divisionForm, setDivisionForm] = useState({});
  const { initialFormData, validationSchema } = formDetails;
  const [formValidationSchema, setFormValidationSchema] = useState({});
  const [show, setShow] = useState(false);

  const handleShowClick = () => setShow(!show);


  useEffect(() => {
    setDivisionForm(initialFormData);
    setFormValidationSchema(validationSchema);
  }, [initialFormData, validationSchema]);

  const handleSubmit = async (values: { password: string }, data: object) => {
    
    const payload = {
      password: values.password,
    };
    const res = await resetPassword(payload);
    
    if (res.status == 200) {
      toast({
        title: "200",
        description: "password change successfully",
        status: "success",
        position: "top-right",
        duration: 2000,
        isClosable: true,
      });
      signOut()
      router.push('auth/sign-in');
    } else {
      toast({
        title: res.status,
        description: res.error,
        status: "error",
        position: "top-right",
        duration: 9000,
        isClosable: true,
      });
    }
  };

  if(isUser) {
    return null
  }

  return (
    <CustomCard w="100%">
      <Flex align="center" w="100%">
        <FormComponent
          ref={formRef}
          validationSchema={formValidationSchema}
          initialValues={divisionForm}
          submitForm={(formValues, formData) => {
            handleSubmit(formValues, formData);
          }}>
          <FormControl w="full">
            <Flex gap={8}>
              <Flex flexDirection="column">
                <FormLabel display="flex" ms="4px" fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                  Change Password<Text color={brandStars}>*</Text>
                </FormLabel>
                <Flex gap={4} w={"full"} justifyContent="space-between">
                  <InputWrapper w={330} form={true} fieldName="password" id="password" fontSize="sm" placeholder="Min. 8 characters" mb="2px" size="lg" type={show ? "text" : "password"} variant="auth" />
                  <Box display="flex">
                    <Icon w={5} h={5} mt={5} color={textColorSecondary} _hover={{ cursor: "pointer" }} as={show ? RiEyeCloseLine : MdOutlineRemoveRedEye} onClick={handleShowClick} />
                  </Box>
                </Flex>
              </Flex>
            </Flex>
            <Button fontSize="sm" type="submit" variant="brand" fontWeight="500" h="50" mb="28px">
              Save
            </Button>
          </FormControl>
        </FormComponent>
      </Flex>
    </CustomCard>
  );
}
